* [U-Boot-Users] [PATCH] PPC440EPx: Optionally enable second I2C bus
@ 2008-02-06 16:10 Mike Nuss
2008-02-16 6:01 ` Stefan Roese
0 siblings, 1 reply; 2+ messages in thread
From: Mike Nuss @ 2008-02-06 16:10 UTC (permalink / raw)
To: u-boot
The option CONFIG_I2C_MULTI_BUS does not have any effect on Sequoia, the
PPC440EPx reference platform, because IIC1 is never enabled. Add Sequoia board
code to turn on IIC1 if CONFIG_I2C_MULTI_BUS is selected.
Signed-off-by: Mike Nuss <mike@terascala.com>
Cc: Stefan Roese <sr@denx.de>
diff --git a/board/amcc/sequoia/sequoia.c b/board/amcc/sequoia/sequoia.c
index 57905de..6bcb3ab 100644
--- a/board/amcc/sequoia/sequoia.c
+++ b/board/amcc/sequoia/sequoia.c
@@ -86,10 +86,13 @@ int board_early_init_f(void)
/* enable USB device */
out_8((u8 *) CFG_BCSR_BASE + 0x09, 0x20);
/* select Ethernet pins */
mfsdr(SDR0_PFC1, sdr0_pfc1);
sdr0_pfc1 = (sdr0_pfc1 & ~SDR0_PFC1_SELECT_MASK) |
SDR0_PFC1_SELECT_CONFIG_4;
+#ifdef CONFIG_I2C_MULTI_BUS
+ sdr0_pfc1 |= ((sdr0_pfc1 & ~SDR0_PFC1_SIS_MASK) | SDR0_PFC1_SIS_IIC1_SEL);
+#endif
mfsdr(SDR0_PFC2, sdr0_pfc2);
sdr0_pfc2 = (sdr0_pfc2 & ~SDR0_PFC2_SELECT_MASK) |
SDR0_PFC2_SELECT_CONFIG_4;
^ permalink raw reply related [flat|nested] 2+ messages in thread
* [U-Boot-Users] [PATCH] PPC440EPx: Optionally enable second I2C bus
2008-02-06 16:10 [U-Boot-Users] [PATCH] PPC440EPx: Optionally enable second I2C bus Mike Nuss
@ 2008-02-16 6:01 ` Stefan Roese
0 siblings, 0 replies; 2+ messages in thread
From: Stefan Roese @ 2008-02-16 6:01 UTC (permalink / raw)
To: u-boot
On Wednesday 06 February 2008, Mike Nuss wrote:
> The option CONFIG_I2C_MULTI_BUS does not have any effect on Sequoia, the
> PPC440EPx reference platform, because IIC1 is never enabled. Add Sequoia
> board code to turn on IIC1 if CONFIG_I2C_MULTI_BUS is selected.
>
> Signed-off-by: Mike Nuss <mike@terascala.com>
> Cc: Stefan Roese <sr@denx.de>
Applied. Thanks.
Best regards,
Stefan
=====================================================================
DENX Software Engineering GmbH, MD: Wolfgang Denk & Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: +49-8142-66989-0 Fax: +49-8142-66989-80 Email: office at denx.de
=====================================================================
^ permalink raw reply [flat|nested] 2+ messages in thread
end of thread, other threads:[~2008-02-16 6:01 UTC | newest]
Thread overview: 2+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2008-02-06 16:10 [U-Boot-Users] [PATCH] PPC440EPx: Optionally enable second I2C bus Mike Nuss
2008-02-16 6:01 ` Stefan Roese
This is a public inbox, see mirroring instructions
@@ -86,10 +86,13 @@ int board_early_init_f(void)
/* enable USB device */
out_8((u8 *) CFG_BCSR_BASE + 0x09, 0x20);
- /* select Ethernet pins */
+ /* select Ethernet (and optionally IIC1) pins */
mfsdr(SDR0_PFC1, sdr0_pfc1);
sdr0_pfc1 = (sdr0_pfc1 & ~SDR0_PFC1_SELECT_MASK) |
for how to clone and mirror all data and code used for this inbox